Step Decorator — yaflux documentation

Skip to main content
`Ctrl`+`K`

# Step Decorator

yaflux._step.step(creates=None, requires=None, mutates=None)

  Decorator to register analysis steps and their results.

  Parameters:

    - creates (str | list[str] | None) – Names of the results this step creates

    - requires (str | list[str] | None) – Names of the results this step requires

    - mutates (str | list[str] | None) – Names of the results this step mutates

  yaflux._step.creates

    Names of the results this step creates

    Type:

      list[str]

  yaflux._step.requires

    Names of the results this step requires

    Type:

      list[str]

  yaflux._step.mutates

    Names of the results this step mutates

    Type:

      list[str]

  yaflux._step.creates_flags

    Names of the flags this step creates

    Type:

      list[str]

  yaflux._step.requires_flags

    Names of the flags this step requires

    Type:

      list[str]

  Return type:

    `Callable`